Get the column value by the index
Get the values for all columns
Allow use of a vector instead of tuples, for when the number of columns are unknow at compile time
or more columns are needed than what can be used with the tuples
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.