IntoParams

Trait IntoParams 

pub trait IntoParams {
    // Required method
    fn to_params(self) -> ParamsType;
}
Types with an associated boolean flag function, named() indiciating support for named or positional parameters.

With both named (as a struct field) or positional (as a Vector or tuple element) parameters, Option<T>, with T an IntoParam, may be used to indicate a nullable argument, wherein the None variant provides a null value.

This crate provides a derive macro for supplying arguments via the fields of a struct and their labels.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoParams for ()

Represents 0 parameters

Source

impl IntoParams for Vec<SqlType>

Allow use of a vector instead of tuples, for run-time-determined parameter count, or for when there are too many parameters to use one of the provided tuple implementations

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> IntoParams for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<B, C, D, E, F, G, H, I, J, K, L, M, N, O> IntoParams for (B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<C, D, E, F, G, H, I, J, K, L, M, N, O> IntoParams for (C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<D, E, F, G, H, I, J, K, L, M, N, O> IntoParams for (D, E, F, G, H, I, J, K, L, M, N, O)

Source

impl<E, F, G, H, I, J, K, L, M, N, O> IntoParams for (E, F, G, H, I, J, K, L, M, N, O)

Source

impl<F, G, H, I, J, K, L, M, N, O> IntoParams for (F, G, H, I, J, K, L, M, N, O)

Source

impl<G, H, I, J, K, L, M, N, O> IntoParams for (G, H, I, J, K, L, M, N, O)

Source

impl<H, I, J, K, L, M, N, O> IntoParams for (H, I, J, K, L, M, N, O)

Source

impl<I, J, K, L, M, N, O> IntoParams for (I, J, K, L, M, N, O)

Source

impl<J, K, L, M, N, O> IntoParams for (J, K, L, M, N, O)

Source

impl<K, L, M, N, O> IntoParams for (K, L, M, N, O)
where K: IntoParam, L: IntoParam, M: IntoParam, N: IntoParam, O: IntoParam,

Source

impl<L, M, N, O> IntoParams for (L, M, N, O)
where L: IntoParam, M: IntoParam, N: IntoParam, O: IntoParam,

Source

impl<M, N, O> IntoParams for (M, N, O)
where M: IntoParam, N: IntoParam, O: IntoParam,

Source

impl<N, O> IntoParams for (N, O)
where N: IntoParam, O: IntoParam,

Source

impl<O> IntoParams for (O,)
where O: IntoParam,

Implementors